Coverage report

# Coverage report: 69%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1202 | 367 | 0 | 69%
jacc/__init__.py | 1 | 0 | 0 | 100%
jacc/admin.py | 508 | 274 | 0 | 46%
jacc/apps.py | 5 | 0 | 0 | 100%
jacc/forms.py | 7 | 0 | 0 | 100%
jacc/helpers.py | 5 | 0 | 0 | 100%
jacc/interests.py | 49 | 5 | 0 | 90%
jacc/locale/__init__.py | 0 | 0 | 0 | 100%
jacc/locale/en/__init__.py | 0 | 0 | 0 | 100%
jacc/locale/fi/__init__.py | 0 | 0 | 0 | 100%
jacc/management/__init__.py | 0 | 0 | 0 | 100%
jacc/management/commands/__init__.py | 0 | 0 | 0 | 100%
jacc/management/commands/invoice_balance.py | 24 | 24 | 0 | 0%
jacc/management/commands/update_invoices.py | 23 | 23 | 0 | 0%
jacc/models.py | 261 | 27 | 0 | 90%
jacc/settle.py | 79 | 14 | 0 | 82%
jacc/templates/__init__.py | 0 | 0 | 0 | 100%
jacc/templates/admin/__init__.py | 0 | 0 | 0 | 100%
jacc/templates/admin/jacc/__init__.py | 0 | 0 | 0 | 100%
jacc/templates/admin/jacc/account/__init__.py | 0 | 0 | 0 | 100%
jacc/templates/admin/jacc/accountentry/__init__.py | 0 | 0 | 0 | 100%
jacc/tests.py | 234 | 0 | 0 | 100%
manage.py | 6 | 0 | 0 | 100%

No items found using the specified filter.